@@ -37,6 +37,12 @@ class AddUserHdfsInfoRequest(RpcRequest):
 	def set_ExtInfo(self,ExtInfo):
 		self.add_query_param('ExtInfo',ExtInfo)
 
+	def get_ClientToken(self):
+		return self.get_query_params().get('ClientToken')
+
+	def set_ClientToken(self,ClientToken):
+		self.add_query_param('ClientToken',ClientToken)
+
 	def get_ClusterId(self):
 		return self.get_query_params().get('ClusterId')
 
