@@ -55,6 +55,12 @@ class CreateServerlessClusterRequest(RpcRequest):
 	def set_EngineVersion(self,EngineVersion):
 		self.add_query_param('EngineVersion',EngineVersion)
 
+	def get_ResourceGroupId(self):
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self,ResourceGroupId):
+		self.add_query_param('ResourceGroupId',ResourceGroupId)
+
 	def get_Engine(self):
 		return self.get_query_params().get('Engine')
 
@@ -73,6 +79,12 @@ class CreateServerlessClusterRequest(RpcRequest):
 	def set_Period(self,Period):
 		self.add_query_param('Period',Period)
 
+	def get_DiskType(self):
+		return self.get_query_params().get('DiskType')
+
+	def set_DiskType(self,DiskType):
+		self.add_query_param('DiskType',DiskType)
+
 	def get_VSwitchId(self):
 		return self.get_query_params().get('VSwitchId')
 
